@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '2.56';
+$CPAN::Perl::Releases::VERSION = '3.48';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -16,7 +16,6 @@ use Exporter;
 our $cache = { };
 our $data =
 {
-"5.003_07" => { id => 'ANDYD' },
 "5.004" => { id => 'CHIPS' },
 "5.004_01" => { id => 'TIMB' },
 "5.004_02" => { id => 'TIMB' },
@@ -145,7 +144,6 @@ our $data =
 "5.21.8" => { id => 'WOLFSAGE' },
 "5.20.2-RC1" => { id => 'SHAY' },
 "5.20.2" => { id => 'SHAY' },
-"5.21.9" => { id => 'XSAWYERX' },
 "5.21.10" => { id => 'SHAY' },
 "5.21.11" => { id => 'SHAY' },
 "5.22.0" => { id => 'RJBS' },
@@ -163,8 +161,56 @@ our $data =
 "5.22.1-RC3" => { id => 'SHAY' },
 "5.22.1-RC4" => { id => 'SHAY' },
 "5.22.1" => { id => 'SHAY' },
-"5.23.6" => { id => 'DAGOLDEN' },
+"5.23.6" => { id => 'DAGOLDEN', noxz => 1 },
 "5.23.7" => { id => 'STEVAN' },
+"5.23.9" => { id => 'ABIGAIL' },
+"5.22.2-RC1" => { id => 'SHAY' },
+"5.24.0-RC1" => { id => 'RJBS' },
+"5.24.0-RC2" => { id => 'RJBS' },
+"5.24.0-RC3" => { id => 'RJBS' },
+"5.22.2" => { id => 'SHAY' },
+"5.24.0-RC4" => { id => 'RJBS' },
+"5.24.0-RC5" => { id => 'RJBS' },
+"5.24.0" => { id => 'RJBS' },
+"5.25.0" => { id => 'RJBS' },
+"5.25.2" => { id => 'WOLFSAGE' },
+"5.22.3-RC1" => { id => 'SHAY' },
+"5.24.1-RC1" => { id => 'SHAY' },
+"5.25.3" => { id => 'SHAY' },
+"5.22.3-RC2" => { id => 'SHAY' },
+"5.24.1-RC2" => { id => 'SHAY' },
+"5.22.3-RC3" => { id => 'SHAY' },
+"5.24.1-RC3" => { id => 'SHAY' },
+"5.25.4" => { id => 'BINGOS' },
+"5.25.5" => { id => 'STEVAN' },
+"5.22.3-RC4" => { id => 'SHAY' },
+"5.24.1-RC4" => { id => 'SHAY' },
+"5.25.6" => { id => 'ARC' },
+"5.25.7" => { id => 'EXODIST' },
+"5.22.3-RC5" => { id => 'SHAY' },
+"5.24.1-RC5" => { id => 'SHAY' },
+"5.22.3" => { id => 'SHAY' },
+"5.24.1" => { id => 'SHAY' },
+"5.25.9" => { id => 'ABIGAIL' },
+"5.25.10" => { id => 'RENEEB' },
+"5.26.0" => { id => 'XSAWYERX' },
+"5.27.1" => { id => 'EHERMAN' },
+"5.22.4-RC1" => { id => 'SHAY' },
+"5.24.2-RC1" => { id => 'SHAY' },
+"5.22.4" => { id => 'SHAY' },
+"5.24.2" => { id => 'SHAY' },
+"5.27.2" => { id => 'ARC' },
+"5.27.3" => { id => 'WOLFSAGE' },
+"5.24.3-RC1" => { id => 'SHAY' },
+"5.26.1-RC1" => { id => 'SHAY' },
+"5.27.4" => { id => 'GENEHACK' },
+"5.24.3" => { id => 'SHAY' },
+"5.26.1" => { id => 'SHAY' },
+"5.27.5" => { id => 'SHAY' },
+"5.27.6" => { id => 'ETHER' },
+"5.27.7" => { id => 'BINGOS' },
+"5.27.8" => { id => 'ABIGAIL' },
+"5.27.9" => { id => 'RENEEB' },
 };
 
 sub perl_tarballs {
@@ -192,7 +238,7 @@ sub perl_tarballs {
   }
   my $foo = { };
   $foo->{'tar.gz'} = "$path/$perl.tar.gz" unless $onlybz2;
-  $foo->{'tar.bz2'} = "$path/$perl.tar.bz2" unless $onlygz;
+  $foo->{'tar.bz2'} = "$path/$perl.tar.bz2" unless $onlygz || $lvers > 5.027005;
   $foo->{'tar.xz'} = "$path/$perl.tar.xz" if $lvers > 5.021005 && !$noxz;
   $cache->{ $vers } = $foo;
   return { %$foo };
@@ -232,7 +278,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 2.56
+version 3.48
 
 =head1 SYNOPSIS
 
@@ -299,7 +345,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Chris Williams.
+This software is copyright (c) 2018 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
